@@ -9,9 +9,13 @@
 
 from climetlab.core.plugins import directories
 import os
-import sys
 import yaml
 from collections import defaultdict
+import logging
+from climetlab.utils.html import css
+
+LOG = logging.getLogger(__name__)
+
 
 YAML_FILES = None
 
@@ -45,6 +49,17 @@ class Entry:
         self.data = data
         self.hidden = data.get("hidden", False)
 
+    def _repr_html_(self):
+        html = [css("table")]
+        html.append("<table>")
+        html.append("<tr><td>%s</td></tr>" % self.name)
+        html.append("<tr><td>%s</td></tr>" % self.kind)
+        html.append("<tr><td>%s</td></tr>" % self.path)
+        html.append("<tr><td><pre>%s</pre></td></tr>" % (yaml.dump(self.data, default_flow_style=False),))
+        html.append("</table>")
+        return "".join(html)
+
+
 
 def _load_yaml_files():
     global YAML_FILES
@@ -62,11 +77,18 @@ def _load_yaml_files():
                     kind = _guess(data)
                     collection = YAML_FILES[kind]
                     if name in collection:
-                        print("Duplicate entry for", kind, name, file=sys.stderr)
-                    collection[name] = Entry(name, kind, path, data)
+                        LOG.warning(
+                            "Duplicate entry for %s %s (using %s, ignoring %s)",
+                            kind,
+                            name,
+                            collection[name].path,
+                            path,
+                        )
+                    else:
+                        collection[name] = Entry(name, kind, path, data)
 
-            except Exception as e:
-                print("Cannot read YAML file", path, e, file=sys.stderr)
+            except Exception:
+                LOG.error("Cannot process YAML file %s", path, exc_info=True)
 
     return YAML_FILES
 
