@@ -3,19 +3,18 @@
 # This software is licensed under the terms of the Apache Licence Version 2.0
 # which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
 # In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation nor
-# does it submit to any jurisdiction.
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
 #
 
 
 class NumpyArrayHelper:
-    def __init__(self, data, field, **kwargs):
+    def __init__(self, data):
         self.data = data
-        self.field = field
-        self.kwargs = kwargs
 
     def plot_map(self, driver):
-        grid = self.field.grid_definition()
+        field = driver.option("field")
+        grid = field.grid_definition()
 
         driver.bounding_box(
             north=grid["north"],
@@ -30,10 +29,8 @@ class NumpyArrayHelper:
             west=grid["west"],
             south_north_increment=grid["south_north_increment"],
             west_east_increment=grid["west_east_increment"],
-            metadata=self.field.metadata(),
+            metadata=field.metadata(),
         )
 
-        driver.apply_kwargs(self.kwargs)
-
 
 helper = NumpyArrayHelper
